@@ -1,4 +1,5 @@
-create.inz.histplot <- function(obj) {
+#' @export
+create.inz.histplot <- function(obj, ...) {
     create.inz.dotplot(obj, hist = TRUE)
 }
 
@@ -11,8 +12,11 @@ plot.inzhist <- function(obj, gen) {
     boxplot <- opts$boxplot
     mean_indicator <- FALSE
     if (!is.null(opts$mean_indicator)) {
-        if (is.logical(opts$mean_indicator)) mean_indicator <- opts$mean_indicator
-        else mean_indicator <- opts$mean_indicator %in% c("grand", "group")
+        if (is.logical(opts$mean_indicator)) {
+            mean_indicator <- opts$mean_indicator
+        } else {
+            mean_indicator <- opts$mean_indicator %in% c("grand", "group")
+        }
     }
 
     addGrid(x = TRUE, gen = gen, opts = opts)
@@ -35,8 +39,11 @@ plot.inzhist <- function(obj, gen) {
     ylim <- c(0, gen$maxcount * 1.05)
 
     GROUP.names <-
-        if (nlev > 1 & opts$internal.labels) names(toplot)
-        else NULL
+        if (nlev > 1 & opts$internal.labels) {
+            names(toplot)
+        } else {
+            NULL
+        }
 
     for (i in 1:nlev) {
         pp <- toplot[[i]]
@@ -77,19 +84,22 @@ plot.inzhist <- function(obj, gen) {
         }
 
         ## Label group
-        if (!is.null(GROUP.names))
+        if (!is.null(GROUP.names)) {
             grid.text(GROUP.names[i],
                 x = 0.01,
                 y = 0.98,
                 just = c("left", "top"),
                 gp = gpar(cex = 0.8)
             )
+        }
     }
 
     seekViewport("VP:histplot-levels")
     upViewport()
 
-    if (!is.null(inflist))
-        if ("comp" %in% names(inflist[[1]]))
+    if (!is.null(inflist)) {
+        if ("comp" %in% names(inflist[[1]])) {
             addUnivarCompLines(inflist)
+        }
+    }
 }
