@@ -56,8 +56,8 @@ test_that("Subsetting replicate weight surveys is correct", {
         n3 = n
     )
 
-    expect_is(inzplot(~f | sex, data = dchis2), "inzplotoutput")
-    expect_is(inzplot(ab30 ~ f | sex, data = dchis2), "inzplotoutput")
-    expect_is(inzplot(n2 ~ n | sex, data = dchis2), "inzplotoutput")
-    expect_is(inzplot(n3 ~ n | sex, data = dchis2), "inzplotoutput")
+    expect_is(inzplot(~f | sex, data = dchis2, plot = FALSE), "inzplotoutput")
+    expect_is(inzplot(ab30 ~ f | sex, data = dchis2, plot = FALSE), "inzplotoutput")
+    expect_is(inzplot(n2 ~ n | sex, data = dchis2, plot = FALSE), "inzplotoutput")
+    expect_is(inzplot(n3 ~ n | sex, data = dchis2, plot = FALSE), "inzplotoutput")
 })
